// authenticate.ts
import { Request, Response, NextFunction } from "express";
import jwt from "jsonwebtoken";
import { PrismaClient } from "@prisma/client";
import { JwtPayload } from "../types";

const JWT_SECRET_KEY_VENDOR = process.env.JWT_SECRET_KEY_VENDOR || "";

export const authorizeApplication = async (
  req: Request,
  res: Response,
  next: NextFunction
) => {
  const accessToken = req.header("Authorization")?.replace("Bearer ", "");

  try {
    if (!accessToken) {
      return res.status(401).json({ error: "Unauthorized: No token provided" });
    }

    // Access Token Verify
    let decodedAccessToken: JwtPayload | null = null;
    try {
      decodedAccessToken = jwt.verify(accessToken, JWT_SECRET_KEY_VENDOR) as JwtPayload;
    } catch (error) {
      console.error(error);
      if (error instanceof jwt.TokenExpiredError) {
        return res.status(401).json({ error: "Unauthorized: Token expired" });
      }
      if (error instanceof jwt.JsonWebTokenError) {
        return res.status(401).json({ error: "Unauthorized: Invalid token" });
      }
      // For other unexpected errors
      return res.status(500).json({ error: "Internal Server Error" });
    }

    if (!decodedAccessToken) {
      return res
        .status(401)
        .json({ error: "Unauthorized: Invalid accessToken token" });
    }
    
    req.user = decodedAccessToken;
    next();
  } catch (error) {
    console.error(error);
    if (error instanceof jwt.TokenExpiredError) {
      return res.status(401).json({ error: "Unauthorized: Token expired" });
    }
    if (error instanceof jwt.JsonWebTokenError) {
      return res.status(401).json({ error: "Unauthorized: Invalid token" });
    }
    // For other unexpected errors
    return res.status(500).json({ error: "Internal Server Error" });
  }
};
